@@ -26,7 +26,7 @@ from gpstime import gpstime, GPSTimeException
 from . import __version__
 from . import const
 from . import layout
-from .scope import set_background, NDScope
+from .scope import NDScope
 
 logging.addLevelName(5, 'DATA')
 logging.basicConfig(
@@ -310,9 +310,6 @@ def main():
         print(yaml.safe_dump(template, default_style=False))
         sys.exit()
 
-    if template.get('black-on-white'):
-        set_background('w')
-
     os.environ['NDSSERVER'] = resolve_ndsserver(args.nds)
 
     app = QApplication([])
@@ -320,6 +317,11 @@ def main():
     app.setStyleSheet("QPushButton { background-color: #CCC }")
     scope = NDScope(template['plots'])
     scope.setWindowTitle('{}: {}'.format(PROG, template.get('window-title', '')))
+    scope.set_font_size(template['font-size'])
+    if template.get('black-on-white'):
+        scope.set_background('w')
+    else:
+        scope.set_background('k')
     scope.show()
 
     if not template['plots'][0]['channels']:
