@@ -10,9 +10,7 @@ except ImportError:
     from PyQt5.QtCore import Qt
 
 from . import util
-
-
-LABEL_FILL = (0, 0, 0, 200)
+from .const import LABEL_FILL
 
 
 class TCursors:
@@ -24,6 +22,22 @@ class TCursors:
     def __init__(self):
         self.plots = []
 
+    def set_font(self, font):
+        """Set text label font"""
+        for plot, lines, diff in self.plots:
+            for cur in lines:
+                cur.label.setFont(font)
+            diff.label.textItem.setFont(font)
+
+    def set_text_color(self, color):
+        """Set color of label text cursor lines"""
+        for plot, lines, diff in self.plots:
+            for cur in lines:
+                cur.label.textItem.setDefaultTextColor(color)
+                cur.pen.setColor(color)
+            diff.label.textItem.setDefaultTextColor(color)
+            diff.pen.setColor(color)
+
     def add_plot(self, plot):
         lines = []
         for index, label in enumerate(['T1', 'T2']):
@@ -52,6 +66,7 @@ class TCursors:
             },
         )
         self.plots.append((plot, lines, diff))
+        self.set_font(plot.font)
 
     def enable(self):
         for plot, lines, diff in self.plots:
@@ -137,6 +152,17 @@ class YCursors:
         )
         self.plot = None
 
+    def set_font(self, font):
+        """Set text label font"""
+        for label in [self.Y1.label, self.Y2.label, self.diff.label]:
+            label.textItem.setFont(font)
+
+    def set_text_color(self, color):
+        """Set color of label text and cursor lines"""
+        for line in [self.Y1, self.Y2, self.diff]:
+            line.label.textItem.setDefaultTextColor(color)
+            line.pen.setColor(color)
+
     def set_plot(self, plot):
         if plot == self.plot:
             return
