@@ -7,8 +7,10 @@ import pyqtgraph as pg
 from pyqtgraph import PlotItem, PlotDataItem, FillBetweenItem
 try:
     from qtpy import QtCore
+    from qtpy.QtGui import QFont, QColor, QPen
 except ImportError:
     from PyQt5 import QtCore
+    from PyQt5.QtGui import QFont, QColor, QPen
 
 from gpstime import gpsnow
 
@@ -16,6 +18,7 @@ from . import util
 from . import const
 from .plotMenu import NDScopePlotMenu
 from . import layout
+from . import legend
 
 
 ##################################################
@@ -114,7 +117,8 @@ class NDScopePlot(PlotItem):
         # hide auto-scale buttons
         self.hideButtons()
         # add legend
-        self.addLegend()
+        self.legend = legend.Legend()
+        self.legend.setParentItem(self.vb)
         self.legend.setVisible(False)
         # show grid lines
         self.showGrid(x=True, y=True, alpha=0.2)
@@ -128,6 +132,14 @@ class NDScopePlot(PlotItem):
         vb = self.getViewBox()
         vb.menu = NDScopePlotMenu(self)
 
+        # If this option is not removed then a default font size will
+        # be set in the generated html that will not overridable by
+        # setting the font.
+        self.titleLabel.opts.pop('size')
+
+        self.font = QFont()
+        self.text_color = QColor('gray')
+
     def add_channel(self, channel, **kwargs):
         """Add channel to plot
 
@@ -162,6 +174,25 @@ class NDScopePlot(PlotItem):
         self._update_title_legend()
         self.channel_removed.emit(channel)
 
+    def set_font(self, font):
+        """Set label and axis font"""
+        self.titleLabel.item.setFont(font)
+        self.legend.setFont(font)
+        self.axes['left']['item'].label.setFont(font)
+        self.axes['bottom']['item'].setTickFont(font)
+        self.axes['left']['item'].setTickFont(font)
+        self.font = font
+
+    def set_text_color(self, color):
+        """Set color of label text and axis lines"""
+        self.titleLabel.setAttr('color', color.name())
+        self.titleLabel.setText(self.titleLabel.text)
+        self.legend.setTextColor(color)
+        self.axes['left']['item'].labelStyle['color'] = color.name()
+        self.axes['bottom']['item'].setPen(QPen(color))
+        self.axes['left']['item'].setPen(QPen(color))
+        self.text_color = color
+
     # SLOT
     def _update_legend_item(self, channel):
         cc = self.channels[channel]
@@ -193,7 +224,7 @@ class NDScopePlot(PlotItem):
         """Set the t axis limits for a given t0"""
         self.setLimits(
             xMin=const.GPS_MIN-t0,
-            xMax=gpsnow()-t0+1,
+            #xMax=gpsnow()-t0+1,
         )
 
     def update(self, data, t0):
