@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import os
+import traceback
 import subprocess
 
 import numpy as np
@@ -7,11 +8,13 @@ import numpy as np
 import pyqtgraph as pg
 try:
     from qtpy import QtGui, QtWidgets, QtCore
-    from qtpy.QtWidgets import QStyle, QFileDialog
+    from qtpy.QtWidgets import QStyle, QFileDialog, QFontDialog
+    from qtpy.QtGui import QFont, QColor
     from qtpy import uic
 except ImportError:
     from PyQt5 import QtGui, QtWidgets, QtCore
-    from PyQt5.QtGui import QStyle, QFileDialog
+    from PyQt5.QtWidgets import QStyle, QFileDialog, QFontDialog
+    from PyQt5.QtGui import QFont, QColor
     from PyQt5 import uic
 
 # NOTE: must be imported after pyqt or else config is reset
@@ -34,12 +37,6 @@ logger = logging.getLogger('SCOPE')
 # CONFIG
 
 
-def set_background(color='k'):
-    if color == 'w':
-        pg.setConfigOption('background', 'w')
-        pg.setConfigOption('foreground', 'k')
-
-
 if os.getenv('ANTIALIAS'):
     pg.setConfigOption('antialias', True)
     logger.info("Anti-aliasing ENABLED")
@@ -48,15 +45,6 @@ if os.getenv('ANTIALIAS'):
 # file:///usr/share/doc/python-pyqtgraph-doc/html/graphicsItems/viewbox.html#pyqtgraph.ViewBox.setMouseMode
 
 
-def _preferred_trend_for_span(span):
-    if span > const.TREND_MAX_SECONDS['sec']:
-        return 'min'
-    elif span > const.TREND_MAX_SECONDS['raw']:
-        return 'sec'
-    else:
-        return 'raw'
-
-
 STATUS_STYLES = {
     "data": "background: rgba(0,100,0,100);",
     "msg": "background: rgba(0,0,100,100);",
@@ -64,6 +52,13 @@ STATUS_STYLES = {
 }
 
 
+TREND_OPTIONS = [
+    'auto',
+    'raw',
+    'sec',
+    'min',
+]
+
 ##################################################
 
 
@@ -169,6 +164,25 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.fetchButton1.clicked.connect(self.update_t0)
         self.fetchButton2.clicked.connect(self.update_range)
 
+        ##########
+        # trend
+
+        self.trendSelectGroup = QtGui.QButtonGroup()
+        # NOTE: the numbers correspond to indices in TREND_OPTIONS
+        self.trendSelectGroup.addButton(self.trendAutoSelect, 0)
+        self.trendSelectGroup.addButton(self.trendRawSelect, 1)
+        self.trendSelectGroup.addButton(self.trendSecSelect, 2)
+        self.trendSelectGroup.addButton(self.trendMinSelect, 3)
+        self.trendSelectGroup.buttonClicked.connect(self._trend_select)
+
+        self.trendRawSecThresh.setValidator(QtGui.QIntValidator())
+        self.trendRawSecThresh.setText(str(const.TREND_TRANS_THRESHOLD['raw/sec']))
+        self.trendRawSecThresh.returnPressed.connect(self._set_trend_rawsec)
+
+        self.trendSecMinThresh.setValidator(QtGui.QIntValidator())
+        self.trendSecMinThresh.setText(str(const.TREND_TRANS_THRESHOLD['sec/min']))
+        self.trendSecMinThresh.returnPressed.connect(self._set_trend_secmin)
+
         ##########
         # trigger
 
@@ -201,6 +215,12 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.cursorYPlot.currentIndexChanged.connect(self._set_y_cursors_plot)
         self.cursorYReset.clicked.connect(self.YCursors.reset)
 
+        ##########
+        # style
+
+        self.fontSize.valueChanged.connect(self.set_font_size)
+        self.backgroundCheckBox.stateChanged.connect(self._background_select)
+
         ##########
         # export
 
@@ -250,6 +270,9 @@ class NDScope(QMainWindow, Ui_MainWindow):
         ##########
         # initial config
 
+        self.font = QFont()
+        self.text_color = QColor('gray')
+
         self._base_ui()
 
         self.plotLayout = self.graphView.addLayout()
@@ -264,7 +287,6 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.graphView.nextRow()
         self.referenceTimeLabel = self.graphView.addLabel(
             "GPS Time",
-            size='11pt',
             #bold=True,
         )
 
@@ -283,6 +305,59 @@ class NDScope(QMainWindow, Ui_MainWindow):
 
     ##########
 
+    def set_font(self, font):
+        self.fontSize.setValue(font.pointSize())
+        referenceTimeLabelFont = QFont(font)
+        referenceTimeLabelFont.setPointSize(font.pointSize() + 2)
+        self.referenceTimeLabel.item.setFont(referenceTimeLabelFont)
+        self.Crosshair.set_font(font)
+        self.TCursors.set_font(font)
+        self.YCursors.set_font(font)
+        self.trigger.set_font(font)
+        for plot in self.plots:
+            plot.set_font(font)
+        self.font = font
+
+    def set_font_size(self, size):
+        """Set font size for plots"""
+        font = QFont(self.font)
+        font.setPointSize(size)
+        self.set_font(font)
+
+    def set_text_color(self, color):
+        """Sets the color of the text in the plots
+
+        labels, axis lines and tick labels, and cursors, crosshair,
+        and trigger levels and text.
+
+        """
+        self.Crosshair.set_text_color(color)
+        self.TCursors.set_text_color(color)
+        self.YCursors.set_text_color(color)
+        self.trigger.set_text_color(color)
+        for plot in self.plots:
+            plot.set_text_color(color)
+        self.text_color = color
+
+    def set_background(self, color='k'):
+        """Sets the color of the background.
+
+        Options are 'w': white, 'k': black
+
+        """
+        if color == 'w':
+            self.graphView.setBackground(QColor('white'))
+            self.referenceTimeLabel.setAttr('color', QColor('black'))
+            self.referenceTimeLabel.setText(self.referenceTimeLabel.text)
+            self.backgroundCheckBox.setCheckState(QtCore.Qt.Checked)
+        elif color == 'k':
+            self.graphView.setBackground(QColor('black'))
+            self.referenceTimeLabel.setAttr('color', QColor('white'))
+            self.referenceTimeLabel.setText(self.referenceTimeLabel.text)
+            self.backgroundCheckBox.setCheckState(QtCore.Qt.Unchecked)
+        else:
+            raise ValueError("background color value must be 'w' or 'k'.")
+
     def _base_ui(self):
         self.startButton.setEnabled(False)
         self.startButton2.setEnabled(False)
@@ -359,6 +434,8 @@ class NDScope(QMainWindow, Ui_MainWindow):
         logger.info(f"creating plot {kwargs}...")
 
         plot = NDScopePlot()
+        plot.set_font(self.font)
+        plot.set_text_color(self.text_color)
         plot.channel_added.connect(self._channel_added)
         plot.channel_removed.connect(self._channel_removed)
         plot.new_plot_request.connect(self.add_plot_handler)
@@ -479,10 +556,19 @@ class NDScope(QMainWindow, Ui_MainWindow):
         start, end = self.get_range()
         return abs(end - start)
 
-    def preferred_trend(self):
+    def preferred_trend(self, online=False):
         """preferred trend for the current time span"""
-        span = self.get_span()
-        return _preferred_trend_for_span(span)
+        trend = TREND_OPTIONS[self.trendSelectGroup.checkedId()]
+        if trend == 'auto':
+            span = self.get_span()
+            if span > const.TREND_TRANS_THRESHOLD['sec/min']:
+                return 'min'
+            elif span > const.TREND_TRANS_THRESHOLD['raw/sec']:
+                return 'sec'
+            else:
+                return 'raw'
+        else:
+            return trend
 
     ##########
     # UI
@@ -491,7 +577,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         """Start online mode
 
         """
-        trend = self.preferred_trend()
+        trend = self.preferred_trend(online=True)
         if trend == 'min':
             self.status_error("Online minute trends not supported.  Try a smaller window.")
             return
@@ -567,8 +653,6 @@ class NDScope(QMainWindow, Ui_MainWindow):
         """update time range on mouse pan/zoom"""
         self.updateGPS()
         self.update_entryWindow()
-        if not self.updateOnRange.isChecked():
-            return
         self.update_tlabel()
         self._data_request()
 
@@ -693,8 +777,9 @@ class NDScope(QMainWindow, Ui_MainWindow):
             return
 
         # if this isn't the trend we need then drop the packet
-        if trend != self.preferred_trend():
-            logger.debug(f"DROP {trend} trend packet")
+        preferred_trend = self.preferred_trend()
+        if trend != preferred_trend:
+            logger.debug(f"DROP {trend} trend packet ({preferred_trend} preferred)")
             return
 
         self.last_data = (trend,) + data.range
@@ -837,6 +922,28 @@ class NDScope(QMainWindow, Ui_MainWindow):
             return
         self.entryEndGreg.setText(util.gpstime_str_greg(gt))
 
+    ##########
+    # TREND
+
+    def _trend_select(self, button):
+        trend = TREND_OPTIONS[self.trendSelectGroup.checkedId()]
+        logger.debug(f"trend select: {trend}")
+        if button == self.trendAutoSelect:
+            self.trendThreshGroup.setEnabled(True)
+        else:
+            self.trendThreshGroup.setEnabled(False)
+        self._data_request()
+        # if self.data.online:
+        #     self.data.online_restart()
+        # else:
+        #     self._data_request()
+
+    def _set_trend_rawsec(self, *args):
+        const.TREND_TRANS_THRESHOLD['raw/sec'] = int(self.trendRawSecThresh.text())
+
+    def _set_trend_secmin(self, *args):
+        const.TREND_TRANS_THRESHOLD['sec/min'] = int(self.trendSecMinThresh.text())
+
     ##########
     # TRIGGER
 
@@ -906,7 +1013,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         self.set_trigger_level(value)
 
     def enable_trigger(self):
-        """enable to the crosshair"""
+        """enable trigger"""
         chan = str(self.triggerSelect.currentText())
         self.set_trigger_channel(chan)
         self.reset_trigger_level()
@@ -915,7 +1022,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         logger.info("trigger enabled")
 
     def disable_trigger(self):
-        """disable to the crosshair"""
+        """disable trigger"""
         self.set_trigger_channel(None)
         span = self.get_span()
         self.set_window(-span, 0)
@@ -1056,6 +1163,21 @@ class NDScope(QMainWindow, Ui_MainWindow):
         else:
             self.disable_y_cursors()
 
+
+    ##########
+    # STYLE
+
+    def font_select_dialog(self):
+        font, ok = QFontDialog.getFont(self.font)
+        if ok:
+            self.set_font(font)
+
+    def _background_select(self, state):
+        if state == QtCore.Qt.Checked:
+            self.set_background('w')
+        else:
+            self.set_background('k')
+
     ##########
     # EXPORT
 
@@ -1132,9 +1254,10 @@ class NDScope(QMainWindow, Ui_MainWindow):
                 path,
             )
             kwargs = dict(
-                bg=pg.getConfigOption('background'),
+                bw=(self.backgroundCheckBox.checkState() == QtCore.Qt.Checked),
                 window_title=self.windowTitle().replace('ndscope: ', ''),
-                window_size=self.get_window()
+                time_window=self.get_window(),
+                font_size=self.font.pointSize(),
             )
 
         else:
@@ -1144,6 +1267,7 @@ class NDScope(QMainWindow, Ui_MainWindow):
         try:
             export_func(*args, **kwargs)
         except Exception as e:
+            logger.info(traceback.format_exc())
             self.status_error(str(e))
             return
 
